@@ -11,8 +11,8 @@
 //!
 //! Pipeline:
 //! * Collect plots using functions in [`build`] module
-//! * Create a canvas using [`render`] module.
-//! * Compute min/max by calling [`render::Canvas::build()`].
+//! * Create a RenderOptions using [`render`] module.
+//! * Compute min/max by calling [`render::RenderOptions::build()`].
 //! * Create tick distributions. (This step can be done automatically using [`Data::plot()`])
 //! * Collect title/xname/yname using [`Data::plot()`] or [`Data::plot_with()`]
 //! * Write everything to svg. [`Plotter::render()`] for no svg tag/css. [`simple_theme::SimpleTheme`] for basic css/svg tag.
@@ -64,7 +64,7 @@ pub mod simple_theme;
 ///
 pub mod prelude {
     pub use super::build::crop::Croppable;
-    pub use super::build::Markerable;
+    pub use super::build::marker::Markerable;
     pub use super::build::PlotIteratorExt;
     pub use super::formatm;
     pub use super::plots;
@@ -86,8 +86,6 @@ use render::*;
 
 use build::PlotIterator;
 
-use std::borrow::Borrow;
-
 /// Shorthand for `disp_const(move |w|write!(w,...))`
 /// Similar to `std::format_args!()` except has a more flexible lifetime.
 #[macro_export]
@@ -98,7 +96,7 @@ macro_rules! formatm {
 }
 
 ///
-/// Macro to chain multiple plots together instead of caling [`chain`](build::PlotIteratorExt::chain) repeatedly.
+/// Macro to chain multiple plots together instead of calling [`chain`](build::PlotIteratorExt::chain) repeatedly.
 ///
 #[macro_export]
 macro_rules! plots {
@@ -138,7 +136,7 @@ macro_rules! plots {
 #[macro_export]
 macro_rules! simple_fmt {
     ($data:expr,$title:expr,$xname:expr,$yname:expr) => {{
-        let canvas = $crate::render::canvas_builder().build();
+        let canvas = $crate::render::render_opt_builder().build();
         let data = canvas.build_moved($data);
         let (bx, by) = data.bounds();
         let xt = $crate::ticks::from_default(bx);
